.. _cmdlntool:

=================
Command Line Tool
=================

KLIFF has a command line tool called :program:`kliff` that can be invoked directly
from the terminal. The command line tool :program:`kliff` has the following
sub-commands:

===========  ========================================================
sub-command  description
===========  ========================================================
test         Test installation
dataset      Count, split, and other operations on dataset.
===========  ========================================================

For all command line tools, you can do::

    $ kliff --help
    $ kliff sub-command --help

to get help (or ``-h`` for short).



